package com.mdd.admin.controller.system;

import com.mdd.admin.service.ISystemAuthPostService;
import com.mdd.admin.validate.commons.IdValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.system.SystemPostCreateValidate;
import com.mdd.admin.validate.system.SystemPostSearchValidate;
import com.mdd.admin.validate.system.SystemPostUpdateValidate;
import com.mdd.admin.vo.system.SystemAuthPostVo;
import com.mdd.common.aop.NotPower;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import com.mdd.common.validator.annotation.IDMust;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"api/system/post"})
@Api(
   tags = {"系统岗位管理"}
)
public class SystemAuthPostController {
   @Resource
   ISystemAuthPostService iSystemAuthPostService;

   @NotPower
   @GetMapping({"/all"})
   @ApiOperation("所有岗位")
   public AjaxResult<List<SystemAuthPostVo>> all() {
      List<SystemAuthPostVo> list = this.iSystemAuthPostService.all();
      return AjaxResult.success(list);
   }

   @GetMapping({"/list"})
   @ApiOperation("岗位列表")
   public AjaxResult<PageResult<SystemAuthPostVo>> list(@Validated PageValidate pageValidate, @Validated SystemPostSearchValidate searchValidate) {
      PageResult<SystemAuthPostVo> list = this.iSystemAuthPostService.list(pageValidate, searchValidate);
      return AjaxResult.success(list);
   }

   @GetMapping({"/detail"})
   @ApiOperation("岗位详情")
   public AjaxResult<SystemAuthPostVo> detail(@Validated @IDMust @RequestParam("id") Integer id) {
      SystemAuthPostVo vo = this.iSystemAuthPostService.detail(id);
      return AjaxResult.success(vo);
   }

   @PostMapping({"/add"})
   @ApiOperation("岗位新增")
   public AjaxResult<Object> add(@Validated @RequestBody SystemPostCreateValidate createValidate) {
      this.iSystemAuthPostService.add(createValidate);
      return AjaxResult.success();
   }

   @PostMapping({"/edit"})
   @ApiOperation("岗位编辑")
   public AjaxResult<Object> edit(@Validated @RequestBody SystemPostUpdateValidate updateValidate) {
      this.iSystemAuthPostService.edit(updateValidate);
      return AjaxResult.success();
   }

   @PostMapping({"/del"})
   @ApiOperation("岗位删除")
   public AjaxResult<Object> del(@Validated @RequestBody IdValidate idValidate) {
      this.iSystemAuthPostService.del(idValidate.getId());
      return AjaxResult.success();
   }
}
